Creates a catNetwork object from a SIF/BIF file.
cnCatnetFromSif(file, numcats=2)
cnCatnetFromBif(file)A catNetwork object
a file name
an integer, the number of node categories
N. Balov
The function imports a graph structure from a SIF file by assigning equal number numcats
of categories for each of its nodes and a random probability model.
Subsequently, the probability model can be changed by calling cnSetProb function.
cnNew, cnCatnetFromEdges, cnSetProb