Learn R Programming

catnet (version 1.13.2)

cnCatnetFromSif: Categorical Network from Simple Interaction File (SIF) and Bayesian Networks Interchange Format (BIF)

Description

Creates a catNetwork object from a SIF/BIF file.

Usage

cnCatnetFromSif(file, numcats=2)
cnCatnetFromBif(file)

Arguments

file
a file name
numcats
an integer, the number of node categories

Value

  • A catNetwork object

Details

The function imports a graph structure from a SIF file by assigning equal number numcats of categories for each of its nodes and a random probability model. Subsequently, the probability model can be changed by calling cnSetProb function.

See Also

cnNew, cnCatnetFromEdges, cnSetProb