catNetwork object from a SIF/BIF file.cnCatnetFromSif(file, numcats=2)
cnCatnetFromBif(file)integer, the number of node categoriescatNetwork objectnumcats
of categories for each of its nodes and a random probability model.
Subsequently, the probability model can be changed by calling cnSetProb function.cnNew, cnCatnetFromEdges, cnSetProb