cnCatnetFromSif: catNetwork from Simple Interaction File (SIF)
Description
Creates a catNetwork object from a SIF file.
Usage
cnCatnetFromSif(file, numCategories=2)
Arguments
file
a file name
numCategories
an integer, the number of node categories
Value
A catNetwork object
Details
The function imports a graph structure from a SIF file by assigning equal number numCategories
of categories for each of its nodes and a random probability model.
Subsequently, the probability model can be changed by calling cnSetProb function.